import java.nio.ByteBuffer;

import org.gdal.gdal.Band;
import org.gdal.gdal.Dataset;
import org.gdal.gdal.Driver;
import org.gdal.gdal.gdal;
import org.gdal.gdalconst.gdalconstConstants;


public class GDALLoader {

	public static void main(String[] args) {

		Dataset dataset1;
		Dataset dataset2;
		
		Band band1;
		
		Driver driver;
		
		gdal.AllRegister();
		
		driver = gdal.GetDriverByName("georaster");
		
		dataset1 = gdal.Open("237898.tif");
		band1 = dataset1.GetRasterBand(1);
		
		int xSize = dataset1.getRasterXSize();
		int ySize = dataset1.getRasterYSize();
		int bands = dataset1.getRasterCount();
		int dType = band1.GetRasterDataType();

		if (dType != gdalconstConstants.GDT_Byte) {
            System.err.println("Only support Byte.");
            System.exit(1);			
		}
		System.out.printf("There are %d bands!\n", bands);
		String stmt = "geor:georaster/georaster@orcl,georaster_table,georaster";		
		String options[] = new String[]{"INSERT=VALUES(102, '237898.tif', SDO_GEOR.INIT('rdt_01',2))"};
	
		long start = System.currentTimeMillis();
		dataset2 = driver.Create(stmt, xSize, ySize, bands, dType, options);
		System.out.println(stmt);
		System.out.println(dataset1.GetGeoTransform()[1]);
		dataset2.SetGeoTransform(dataset1.GetGeoTransform());
		dataset2.SetProjection(dataset1.GetProjection());
		
		for(int i = 0; i < dataset1.GetGeoTransform().length; i ++)
			System.out.printf("%f ", dataset1.GetGeoTransform()[i]);
		
		for(int i = 0; i < dataset2.GetGeoTransform().length; i ++)
			System.out.printf("%f ", dataset2.GetGeoTransform()[i]);
		
		
		ByteBuffer buffer = ByteBuffer.allocateDirect(xSize * 1 * bands);
		int[] bandList = new int[bands];
		for( int i = 0; i < bands; i ++)
			bandList[i] = i + 1;
		
		for( int i =0; i < ySize; i++ ) {
			System.out.printf("Process line:%d\n", i, buffer);
			dataset1.ReadRaster_Direct(0, i, xSize, 1, xSize, 1, dType, buffer, bandList);
			dataset2.WriteRaster_Direct(0, i, xSize, 1, xSize, 1, dType, buffer, bandList);
		}
		dataset2.FlushCache();
		
		long duration = System.currentTimeMillis() - start;
		
		System.out.println("generate a new georaster : " + dataset2.GetDescription());
		System.out.printf("Duration:%d.\n", duration);
		
		dataset1.delete();
		dataset2.delete();		
	}

}


